#!/bin/sh
#
# This script comes with no warranties at all - see the GNU General Public Licence
# version 2 or greater for details and for the only terms under which you are
# permitted to distribute this code or any derivatives of it.
#
# This script is Copyright (C) 2003 Leon Brooks <leon@cyberknights.com.au>
#
# This path is /etc/Ralink/RT2400 in real life, set here for testing.
RAPATH=/tmp/Ralink
#
# guess a name, else use "random"
if [ "$1" == "" ]; then
	NAME=$(hostname)
	if [ "$NAME" = "${NAME/#[^.]*.}" ]; then
		NAME=$(hostname -f)
		if [ "$NAME" = "${NAME/#[^.]*.}" ]; then
			NAME=random
		else
			NAME=${NAME/#[^.]*.}
		fi
	else
		NAME=${NAME/#[^.]*.}
	fi
else
	NAME=$1
fi
NAMELEN=${#NAME}
#
# Too long? Truncate it.
if [ $NAMELEN -gt 32 ]; then
	NAME=${NAME:0:32}
	NAMELEN=32
fi
#
# Too short? Back to "random" again.
if [ $NAMELEN -lt 1 ]; then
	NAME=random
	NAMELEN=6
fi
#
# Make sure we've got somewhere to put the generated files.
mkdir -p $RAPATH
KF=$(mktemp /tmp/specify.$PID.XXXXXX)
#
# Make two keys (for luck).
dd if=/dev/random bs=1 count=13 > $KF 2>/dev/null
dd if=/dev/random bs=1 count=13 > $KF.2 2>/dev/null
#
# One file needs the ASCII-hex version
KEY=$(hexdump -e '/1 "%02X"' < $KF)
KEY2=$(hexdump -e '/1 "%02X"' < $KF.2)
#
# Pad the names out to 32 each, plus sundry filler bytes in between.
echo -n $NAME | dd ibs=33 conv=sync >$KF.dat 2>/dev/null
echo -n $NAME | dd ibs=35 conv=sync >>$KF.dat 2>/dev/null
#
# Write the name length in (will never be larger than a byte).
echo -ne "\\$(printf %o $NAMELEN)" >>$KF.dat
#
# Write a chunk of default values.
cat RT2400.dat.chunk1 >>$KF.dat
#
# Write a binary 104-bit WEP key value.
cat $KF >>$KF.dat
rm -f $KF
#
# Write some zero fill.
dd if=/dev/zero ibs=1 count=14 >>$KF.dat 2>/dev/null
#
# Write another binary 104-bit WEP key value.
cat $KF.2 >>$KF.dat
rm -f $KF.2
#
# Add another chunk of default values.
cat RT2400.dat.chunk2 >>$KF.dat
mv -f $KF.dat $RAPATH/RT2400.dat
#
# Do basically the same thing with the "ASCII" version of it; this file
# can contain multiple profiles, which are apparently binarified and
# written to the .dat to change profiles.
echo -n $NAME | dd ibs=33 conv=sync >$KF.pro 2>/dev/null
echo -n $NAME | dd ibs=35 conv=sync >>$KF.pro 2>/dev/null
echo -ne "\\$(printf %o $NAMELEN)" >>$KF.pro
cat RT2400.pro.chunk1 >>$KF.pro
echo -n $KEY >>$KF.pro
dd if=/dev/zero ibs=1 count=1 >>$KF.pro 2>/dev/null
echo -n $KEY2 >>$KF.pro
cat RT2400.pro.chunk2 >>$KF.pro
mv -f $KF.pro $RAPATH/RT2400.pro
#
# Edit the text file to reflect the changes we made to the binaries.
sed <RT2400.cfg -e "s/generic/$NAME/" > $RAPATH/RT2400.cfg
# end
